@@ -1,23 +1,11 @@
 #
 # Copyright (c) SAS Institute Inc.
+# SPDX-License-Identifier: Apache-2.0
+# this has been significantly modified from the original#
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-#
+# Visit https://aboutcode.org and https://github.com/nexB/univers for support and download.
 
 
-"""
-Test version handling
-"""
 import unittest
 
 from univers.maven import Version
@@ -136,7 +124,7 @@ class TestRestriction(unittest.TestCase):
         assert 1 < r1
 
     def test_string_repr(self):
-        for input in (
+        for test in (
             "[1.0]",
             "[1.0,)",
             "[1.0,2.0]",
@@ -146,8 +134,7 @@ class TestRestriction(unittest.TestCase):
             "[,2.0)",
             "(,2.0)",
         ):
-            actual = str(Restriction(input))
-            assert input == actual, "Restriction(%s) == %s, wanted %s" % (input, actual, input)
+            assert str(Restriction(test)) == test
 
 
 class TestVersion(unittest.TestCase):
@@ -232,7 +219,7 @@ class TestVersion(unittest.TestCase):
             ("1-final", (1,)),
             ("1.0-CR", (1, ("rc",))),
             ("1-cr", (1, ("rc",))),
-            # test some transistion
+            # test some transition
             ("1.0-alpha1", (1, ("alpha", (1,)))),
             ("1.0-alpha2", (1, ("alpha", (2,)))),
             ("1.0.0alpha1", (1, ("alpha", (1,)))),
@@ -318,31 +305,31 @@ class TestVersion(unittest.TestCase):
 
         unicode_version_numbers = (
             # again, but with unicode input
-            u"2.0",
-            u"2-1",
-            u"2.0.a",
-            u"2.0.0.a",
-            u"2.0.2",
-            u"2.0.123",
-            u"2.1.0",
-            u"2.1-a",
-            u"2.1b",
-            u"2.1-x",
-            u"2.1-1",
-            u"2.1.0.1",
-            u"2.2",
-            u"2.123",
-            u"11.a2",
-            u"11.a11",
-            u"11.b2",
-            u"11.b11",
-            u"11.m2",
-            u"11.m11",
-            u"11",
-            u"11.a",
-            u"11b",
-            u"11c",
-            u"11m",
+            "2.0",
+            "2-1",
+            "2.0.a",
+            "2.0.0.a",
+            "2.0.2",
+            "2.0.123",
+            "2.1.0",
+            "2.1-a",
+            "2.1b",
+            "2.1-x",
+            "2.1-1",
+            "2.1.0.1",
+            "2.2",
+            "2.123",
+            "11.a2",
+            "11.a11",
+            "11.b2",
+            "11.b11",
+            "11.m2",
+            "11.m11",
+            "11",
+            "11.a",
+            "11b",
+            "11c",
+            "11m",
         )
         for idx, low in enumerate(unicode_version_numbers[:-1]):
             for high in unicode_version_numbers[idx + 1 :]:
@@ -395,29 +382,29 @@ class TestVersion(unittest.TestCase):
         self._assert_version_equal("1m3", "1MILESTONE3")
 
         # unicode
-        self._assert_version_equal(u"1", "1")
-        self._assert_version_equal(u"1", "1.0")
-        self._assert_version_equal(u"1", "1.0.0")
-        self._assert_version_equal(u"1.0", "1.0.0")
-        self._assert_version_equal(u"1", "1-0")
-        self._assert_version_equal(u"1", "1.0-0")
-        self._assert_version_equal(u"1.0", "1.0-0")
+        self._assert_version_equal("1", "1")
+        self._assert_version_equal("1", "1.0")
+        self._assert_version_equal("1", "1.0.0")
+        self._assert_version_equal("1.0", "1.0.0")
+        self._assert_version_equal("1", "1-0")
+        self._assert_version_equal("1", "1.0-0")
+        self._assert_version_equal("1.0", "1.0-0")
 
-        self._assert_version_equal("1", u"1")
-        self._assert_version_equal("1", u"1.0")
-        self._assert_version_equal("1", u"1.0.0")
-        self._assert_version_equal("1.0", u"1.0.0")
-        self._assert_version_equal("1", u"1-0")
-        self._assert_version_equal("1", u"1.0-0")
-        self._assert_version_equal("1.0", u"1.0-0")
+        self._assert_version_equal("1", "1")
+        self._assert_version_equal("1", "1.0")
+        self._assert_version_equal("1", "1.0.0")
+        self._assert_version_equal("1.0", "1.0.0")
+        self._assert_version_equal("1", "1-0")
+        self._assert_version_equal("1", "1.0-0")
+        self._assert_version_equal("1.0", "1.0-0")
 
-        self._assert_version_equal(u"1", u"1")
-        self._assert_version_equal(u"1", u"1.0")
-        self._assert_version_equal(u"1", u"1.0.0")
-        self._assert_version_equal(u"1.0", u"1.0.0")
-        self._assert_version_equal(u"1", u"1-0")
-        self._assert_version_equal(u"1", u"1.0-0")
-        self._assert_version_equal(u"1.0", u"1.0-0")
+        self._assert_version_equal("1", "1")
+        self._assert_version_equal("1", "1.0")
+        self._assert_version_equal("1", "1.0.0")
+        self._assert_version_equal("1.0", "1.0.0")
+        self._assert_version_equal("1", "1-0")
+        self._assert_version_equal("1", "1.0-0")
+        self._assert_version_equal("1.0", "1.0-0")
 
     def test_version_compare(self):
         self._assert_version_order("1", "2")
@@ -443,74 +430,74 @@ class TestVersion(unittest.TestCase):
         self._assert_version_order("2.0.1", "2.0.1-123")
         self._assert_version_order("2.0.1-xyz", "2.0.1-123")
         # unicode input
-        self._assert_version_order(u"1", "2")
-        self._assert_version_order(u"1.5", "2")
-        self._assert_version_order(u"1", "2.5")
-        self._assert_version_order(u"1.0", "1.1")
-        self._assert_version_order(u"1.1", "1.2")
-        self._assert_version_order(u"1.0.0", "1.1")
-        self._assert_version_order(u"1.0.1", "1.1")
-        self._assert_version_order(u"1.1", "1.2.0")
-        self._assert_version_order(u"1.0-alpha-1", "1.0")
-        self._assert_version_order(u"1.0-alpha-1", "1.0-alpha-2")
-        self._assert_version_order(u"1.0-alpha-1", "1.0-beta-1")
-        self._assert_version_order(u"1.0-beta-1", "1.0-SNAPSHOT")
-        self._assert_version_order(u"1.0-SNAPSHOT", "1.0")
-        self._assert_version_order(u"1.0-alpha-1-SNAPSHOT", "1.0-alpha-1")
-        self._assert_version_order(u"1.0", "1.0-1")
-        self._assert_version_order(u"1.0-1", "1.0-2")
-        self._assert_version_order(u"1.0.0", "1.0-1")
-        self._assert_version_order(u"2.0-1", "2.0.1")
-        self._assert_version_order(u"2.0.1-klm", "2.0.1-lmn")
-        self._assert_version_order(u"2.0.1", "2.0.1-xyz")
-        self._assert_version_order(u"2.0.1", "2.0.1-123")
-        self._assert_version_order(u"2.0.1-xyz", "2.0.1-123")
+        self._assert_version_order("1", "2")
+        self._assert_version_order("1.5", "2")
+        self._assert_version_order("1", "2.5")
+        self._assert_version_order("1.0", "1.1")
+        self._assert_version_order("1.1", "1.2")
+        self._assert_version_order("1.0.0", "1.1")
+        self._assert_version_order("1.0.1", "1.1")
+        self._assert_version_order("1.1", "1.2.0")
+        self._assert_version_order("1.0-alpha-1", "1.0")
+        self._assert_version_order("1.0-alpha-1", "1.0-alpha-2")
+        self._assert_version_order("1.0-alpha-1", "1.0-beta-1")
+        self._assert_version_order("1.0-beta-1", "1.0-SNAPSHOT")
+        self._assert_version_order("1.0-SNAPSHOT", "1.0")
+        self._assert_version_order("1.0-alpha-1-SNAPSHOT", "1.0-alpha-1")
+        self._assert_version_order("1.0", "1.0-1")
+        self._assert_version_order("1.0-1", "1.0-2")
+        self._assert_version_order("1.0.0", "1.0-1")
+        self._assert_version_order("2.0-1", "2.0.1")
+        self._assert_version_order("2.0.1-klm", "2.0.1-lmn")
+        self._assert_version_order("2.0.1", "2.0.1-xyz")
+        self._assert_version_order("2.0.1", "2.0.1-123")
+        self._assert_version_order("2.0.1-xyz", "2.0.1-123")
 
-        self._assert_version_order("1", u"2")
-        self._assert_version_order("1.5", u"2")
-        self._assert_version_order("1", u"2.5")
-        self._assert_version_order("1.0", u"1.1")
-        self._assert_version_order("1.1", u"1.2")
-        self._assert_version_order("1.0.0", u"1.1")
-        self._assert_version_order("1.0.1", u"1.1")
-        self._assert_version_order("1.1", u"1.2.0")
-        self._assert_version_order("1.0-alpha-1", u"1.0")
-        self._assert_version_order("1.0-alpha-1", u"1.0-alpha-2")
-        self._assert_version_order("1.0-alpha-1", u"1.0-beta-1")
-        self._assert_version_order("1.0-beta-1", u"1.0-SNAPSHOT")
-        self._assert_version_order("1.0-SNAPSHOT", u"1.0")
-        self._assert_version_order("1.0-alpha-1-SNAPSHOT", u"1.0-alpha-1")
-        self._assert_version_order("1.0", u"1.0-1")
-        self._assert_version_order("1.0-1", u"1.0-2")
-        self._assert_version_order("1.0.0", u"1.0-1")
-        self._assert_version_order("2.0-1", u"2.0.1")
-        self._assert_version_order("2.0.1-klm", u"2.0.1-lmn")
-        self._assert_version_order("2.0.1", u"2.0.1-xyz")
-        self._assert_version_order("2.0.1", u"2.0.1-123")
-        self._assert_version_order("2.0.1-xyz", u"2.0.1-123")
+        self._assert_version_order("1", "2")
+        self._assert_version_order("1.5", "2")
+        self._assert_version_order("1", "2.5")
+        self._assert_version_order("1.0", "1.1")
+        self._assert_version_order("1.1", "1.2")
+        self._assert_version_order("1.0.0", "1.1")
+        self._assert_version_order("1.0.1", "1.1")
+        self._assert_version_order("1.1", "1.2.0")
+        self._assert_version_order("1.0-alpha-1", "1.0")
+        self._assert_version_order("1.0-alpha-1", "1.0-alpha-2")
+        self._assert_version_order("1.0-alpha-1", "1.0-beta-1")
+        self._assert_version_order("1.0-beta-1", "1.0-SNAPSHOT")
+        self._assert_version_order("1.0-SNAPSHOT", "1.0")
+        self._assert_version_order("1.0-alpha-1-SNAPSHOT", "1.0-alpha-1")
+        self._assert_version_order("1.0", "1.0-1")
+        self._assert_version_order("1.0-1", "1.0-2")
+        self._assert_version_order("1.0.0", "1.0-1")
+        self._assert_version_order("2.0-1", "2.0.1")
+        self._assert_version_order("2.0.1-klm", "2.0.1-lmn")
+        self._assert_version_order("2.0.1", "2.0.1-xyz")
+        self._assert_version_order("2.0.1", "2.0.1-123")
+        self._assert_version_order("2.0.1-xyz", "2.0.1-123")
 
-        self._assert_version_order(u"1", u"2")
-        self._assert_version_order(u"1.5", u"2")
-        self._assert_version_order(u"1", u"2.5")
-        self._assert_version_order(u"1.0", u"1.1")
-        self._assert_version_order(u"1.1", u"1.2")
-        self._assert_version_order(u"1.0.0", u"1.1")
-        self._assert_version_order(u"1.0.1", u"1.1")
-        self._assert_version_order(u"1.1", u"1.2.0")
-        self._assert_version_order(u"1.0-alpha-1", u"1.0")
-        self._assert_version_order(u"1.0-alpha-1", u"1.0-alpha-2")
-        self._assert_version_order(u"1.0-alpha-1", u"1.0-beta-1")
-        self._assert_version_order(u"1.0-beta-1", u"1.0-SNAPSHOT")
-        self._assert_version_order(u"1.0-SNAPSHOT", u"1.0")
-        self._assert_version_order(u"1.0-alpha-1-SNAPSHOT", u"1.0-alpha-1")
-        self._assert_version_order(u"1.0", u"1.0-1")
-        self._assert_version_order(u"1.0-1", u"1.0-2")
-        self._assert_version_order(u"1.0.0", u"1.0-1")
-        self._assert_version_order(u"2.0-1", u"2.0.1")
-        self._assert_version_order(u"2.0.1-klm", u"2.0.1-lmn")
-        self._assert_version_order(u"2.0.1", u"2.0.1-xyz")
-        self._assert_version_order(u"2.0.1", u"2.0.1-123")
-        self._assert_version_order(u"2.0.1-xyz", u"2.0.1-123")
+        self._assert_version_order("1", "2")
+        self._assert_version_order("1.5", "2")
+        self._assert_version_order("1", "2.5")
+        self._assert_version_order("1.0", "1.1")
+        self._assert_version_order("1.1", "1.2")
+        self._assert_version_order("1.0.0", "1.1")
+        self._assert_version_order("1.0.1", "1.1")
+        self._assert_version_order("1.1", "1.2.0")
+        self._assert_version_order("1.0-alpha-1", "1.0")
+        self._assert_version_order("1.0-alpha-1", "1.0-alpha-2")
+        self._assert_version_order("1.0-alpha-1", "1.0-beta-1")
+        self._assert_version_order("1.0-beta-1", "1.0-SNAPSHOT")
+        self._assert_version_order("1.0-SNAPSHOT", "1.0")
+        self._assert_version_order("1.0-alpha-1-SNAPSHOT", "1.0-alpha-1")
+        self._assert_version_order("1.0", "1.0-1")
+        self._assert_version_order("1.0-1", "1.0-2")
+        self._assert_version_order("1.0.0", "1.0-1")
+        self._assert_version_order("2.0-1", "2.0.1")
+        self._assert_version_order("2.0.1-klm", "2.0.1-lmn")
+        self._assert_version_order("2.0.1", "2.0.1-xyz")
+        self._assert_version_order("2.0.1", "2.0.1-123")
+        self._assert_version_order("2.0.1-xyz", "2.0.1-123")
 
     def test_compare(self):
         assert 1 < Version("1.0")
@@ -633,9 +620,9 @@ class TestVersionRange(unittest.TestCase):
         assert 1 < vr1
 
     def test_str(self):
-        for input in ("[1.0,2.0]", "1.0"):
-            actual = str(VersionRange(input))
-            assert input == actual, "VersionRange(%s) == %s, wanted %s" % (input, actual, input)
+        for inp in ("[1.0,2.0]", "1.0"):
+            actual = str(VersionRange(inp))
+            assert inp == actual, "VersionRange(%s) == %s, wanted %s" % (inp, actual, inp)
 
     def test_fromversion(self):
         v = Version("1.0")
